@@ -3,8 +3,8 @@ from typing import Optional
 
 from textacy.preprocessing.resources import RE_NUMBER
 
-from .base import BaseProcessor
-from ..exceptions import TDSValueError
+from textdatasetcleaner.exceptions import TDCValueError
+from textdatasetcleaner.processors.base import BaseProcessor
 
 
 class FilterNumbersProcessor(BaseProcessor):
@@ -15,7 +15,7 @@ class FilterNumbersProcessor(BaseProcessor):
     def __init__(self, mode: str = 'remove_line', replace_with: str = ' '):
         allowed = ['remove_line', 'replace']
         if mode not in allowed:
-            raise TDSValueError(f'Wrong mode for {self.name} processor: {mode}, allowed only: {allowed}')
+            raise TDCValueError(f'Wrong mode for {self.name} processor: {mode}, allowed only: {allowed}')
 
         self.mode = mode
         self.replace_with = replace_with
