@@ -1,7 +1,7 @@
-from typing import Optional
 from pathlib import Path
+from typing import Optional
 
-from .base import BaseProcessor
+from textdatasetcleaner.processors.base import BaseProcessor
 
 
 class LineStripProcessor(BaseProcessor):
@@ -10,6 +10,4 @@ class LineStripProcessor(BaseProcessor):
     __processor_type__ = 'line'
 
     def process_line(self, line: str) -> Optional[str]:
-        line = line.strip()
-
-        return line
+        return line.strip()
