@@ -1,10 +1,10 @@
 from pathlib import Path
 from typing import Optional
 
-from textacy.preprocessing import normalize_unicode
+from textacy.preprocessing import normalize_unicode  # type: ignore
 
-from .base import BaseProcessor
-from ..exceptions import TDSValueError
+from textdatasetcleaner.exceptions import TDCValueError
+from textdatasetcleaner.processors.base import BaseProcessor
 
 
 class NormalizeUnicodeProcessor(BaseProcessor):
@@ -15,11 +15,9 @@ class NormalizeUnicodeProcessor(BaseProcessor):
     def __init__(self, form: str = 'NFKC'):
         allowed = ['NFC', 'NFD', 'NFKC', 'NFKD']
         if form not in allowed:
-            raise TDSValueError(f'Wrong form for {self.name} processor: {form}, allowed only: {allowed}')
+            raise TDCValueError(f'Wrong form for {self.name} processor: {form}, allowed only: {allowed}')
 
         self.form = form
 
     def process_line(self, line: str) -> Optional[str]:
-        line = normalize_unicode(line, form=self.form)
-
-        return line
+        return normalize_unicode(line, form=self.form)
